.. _sunpy-coordinates-other-api:

Reference/API for supporting coordinates modules
************************************************

The parts of the following modules that are useful to a typical user are already imported into the `sunpy.coordinates` namespace.

.. automodapi:: sunpy.coordinates.frames

.. automodapi:: sunpy.coordinates.metaframes

.. automodapi:: sunpy.coordinates.transformations

.. automodapi:: sunpy.coordinates.wcs_utils
